Quantum Input/Output
=======================

A common problem in quantum circuits deals with how to get classical
data in and out of a quantum computer.  Forge provides a method to
create a circuit from an array of numerical data which loads that
data into a quantum circuit.

.. autofunction:: qcware.qio.loader
